@@ -4,7 +4,7 @@
 #' for a set of taxonomy UIDs using eutils esummary.
 #'
 #' @export
-#' @param id (character) NCBI taxonomy uids to retrieve information for.
+#' @param id (character) NCBI taxonomy uids to retrieve information for. See Details.
 #' @param ... Curl options passed on to \code{\link[httr]{GET}}
 #' @return A \code{data.frame} with the following rows:
 #'   \describe{
@@ -13,6 +13,10 @@
 #'     \item{rank}{The taxonomic rank (e.g. 'Genus')}
 #'   }
 #' @author Zachary Foster \email{zacharyfoster1989@@Sgmail.com}
+#' @details If your input vector or list of NCBI IDs is longer than about 8000 characters
+#' (use \code{nchar(paste(ids, collapse = "+"))}), split the list up into chunks since
+#' at about that number of characters you will run into the HTTP 414 error
+#' "Request-URI Too Long".
 #' @examples \dontrun{
 #' ncbi_get_taxon_summary(c(1430660, 4751))
 #'
@@ -25,6 +29,7 @@ ncbi_get_taxon_summary <- function(id, ...) {
   if (is.null(id)) return(NULL)
   if (length(id) <= 1 && is.na(id)) return(NA)
   id <- as.character(id)
+  if (nchar(paste(id, collapse = "+")) > 8000L) message("You may want to split your ids up into chunks")
   # Make eutils esummary query ---------------------------------------------------------------------
   base_url <- "http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esummary.fcgi?db=taxonomy"
   query <- paste0(base_url, "&id=", paste(id, collapse = "+"))
