@@ -15,7 +15,7 @@ tp_refs <- function(id, key = NULL, ...) {
   args <- tc(list(apikey = key, format = 'json'))
   tmp <- GET(url, query = args, ...)
   stop_for_status(tmp)
-  tmp2 <- content(tmp, as = "text")
+  tmp2 <- con_utf8(tmp)
   res <- jsonlite::fromJSON(tmp2, FALSE)
   do.call(rbind.fill, lapply(res, function(x){
     x <- x$Reference
