@@ -1,11 +1,13 @@
 # tests for col_downstream fxn in taxize
 context("col_downstream")
 
-temp4 <- col_downstream(name="Animalia", downto = "Phylum", verbose = FALSE)
-temp5 <- col_downstream(name="Plantae", downto = "Phylum", verbose = FALSE)
-temp6 <- col_downstream(name="Salicaceae", downto = "Genus", verbose = FALSE)
-
 test_that("col_downstream returns the correct class", {
+  skip_on_cran()
+
+  temp4 <- col_downstream(name="Animalia", downto = "Phylum", verbose = FALSE)
+  temp5 <- col_downstream(name="Plantae", downto = "Phylum", verbose = FALSE)
+  temp6 <- col_downstream(name="Salicaceae", downto = "Genus", verbose = FALSE)
+
   expect_is(temp4, "list")
   expect_is(temp5, "list")
   expect_is(temp6, "list")
@@ -17,6 +19,4 @@ test_that("col_downstream returns the correct class", {
 test_that("gives what's expected on input errors", {
   library("plyr")
   expect_message(col_downstream(name="Pinus contorta", downto = "Species")[[1]], "Try adjusting")
-#   expect_is(col_downstream(name=c("Buteo","Puma"), downto = "Family"), "list")
-#   expect_message(col_downstream(name=c("Buteo","Puma"), downto = "Family"), "Try adjusting")
 })
